Documentation
¶
Overview ¶
Package lib contains all project logic.
Index ¶
Constants ¶
const ( Markdown = ".md" Gocode = ".go" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type App ¶
App models current application
type Config ¶
Config models an entity config reader
func (*Config) BooleanDefault ¶
BooleanDefault function gets config property from default section or use default boolean value
func (*Config) Default ¶
Default function gets config property from default section
func (*Config) File ¶
File function returns configuration file path
type File ¶
type Logger ¶
Logger represents a logger strut
type Server ¶
Server represents web server logic and attributes
func (*Server) ServeHTTP ¶
func (s *Server) ServeHTTP(rw http.ResponseWriter, r *http.Request)
ServerHTTP is the handler function to publish into web server
Source Files
¶
- app.go
- config.go
- file.go
- log.go
- server.go
Click to show internal directories.
Click to hide internal directories.